# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import printnanny_api_client
from printnanny_api_client.api.users_api import UsersApi  # noqa: E501
from printnanny_api_client.rest import ApiException


class TestUsersApi(unittest.TestCase):
    """UsersApi unit test stubs"""

    def setUp(self):
        self.api = printnanny_api_client.api.users_api.UsersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_users_me_retrieve(self):
        """Test case for users_me_retrieve

        """
        pass

    def test_users_partial_update(self):
        """Test case for users_partial_update

        """
        pass

    def test_users_retrieve(self):
        """Test case for users_retrieve

        """
        pass

    def test_users_update(self):
        """Test case for users_update

        """
        pass


if __name__ == '__main__':
    unittest.main()
