# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.telemetry_event_polymorphic import TelemetryEventPolymorphic  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestTelemetryEventPolymorphic(unittest.TestCase):
    """TelemetryEventPolymorphic unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTelemetryEventPolymorphic(self):
        """Test TelemetryEventPolymorphic"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
